# geoh
Transform a geoJSON into a list of geohashes that intersect with it.


## Install

`pip install geoh`


## How to use it

```
import geoh

geohashes = geoh.geohashes(geojson=geojson, precision=6)

```
